@@ -15,6 +15,7 @@ and the chomping modifiers:
 """
 
 import pytest
+import platform
 
 import ruamel.yaml
 from ruamel.yaml.compat import ordereddict
@@ -32,6 +33,8 @@ class TestYAML:
         a: '12345'
         """)
 
+    @pytest.mark.skipif(platform.python_implementation() == 'Jython',
+                    reason="Jython throws RepresenterError")
     def test_preserve_string(self):
         round_trip("""
             a: |
@@ -39,6 +42,8 @@ class TestYAML:
               def
             """, intermediate=dict(a='abc\ndef\n'))
 
+    @pytest.mark.skipif(platform.python_implementation() == 'Jython',
+                    reason="Jython throws RepresenterError")
     def test_preserve_string_strip(self):
         s = """
             a: |-
@@ -48,6 +53,8 @@ class TestYAML:
             """
         round_trip(s, intermediate=dict(a='abc\ndef'))
 
+    @pytest.mark.skipif(platform.python_implementation() == 'Jython',
+                    reason="Jython throws RepresenterError")
     def test_preserve_string_keep(self):
             # with pytest.raises(AssertionError) as excinfo:
             round_trip("""
@@ -59,6 +66,8 @@ class TestYAML:
             b: x
             """, intermediate=dict(a='ghi\njkl\n\n\n', b='x'))
 
+    @pytest.mark.skipif(platform.python_implementation() == 'Jython',
+                    reason="Jython throws RepresenterError")
     def test_preserve_string_keep_at_end(self):
         # at EOF you have to specify the ... to get proper "closure"
         # of the multiline scalar
